Class: Array
Instance Method Summary collapse
-
#to_param ⇒ Object
Calls
to_paramon all its elements and joins the result with slashes. -
#to_query(key) ⇒ Object
Converts an array into a string suitable for use as a URL query string, using the given
keyas the param name.
Instance Method Details
#to_param ⇒ Object
Calls to_param on all its elements and joins the result with slashes. This is used by url_for in Action Pack.
39 40 41 |
# File 'lib/req/query.rb', line 39 def to_param collect { |e| e.to_param }.join '/' end |
#to_query(key) ⇒ Object
Converts an array into a string suitable for use as a URL query string, using the given key as the param name.
['Rails', 'coding'].to_query('hobbies') # => "hobbies%5B%5D=Rails&hobbies%5B%5D=coding"
47 48 49 50 |
# File 'lib/req/query.rb', line 47 def to_query(key) prefix = "#{key}[]" collect { |value| value.to_query(prefix) }.join '&' end |