Class: Object

Inherits:
BasicObject
Defined in:
lib/req/query.rb

Overview

FOLLOWING CODE IS FROM ‘rails/activesupport’

Instance Method Summary collapse

Instance Method Details

#to_paramObject

Alias of to_s.



4
5
6
# File 'lib/req/query.rb', line 4

def to_param
  to_s
end

#to_query(key) ⇒ Object

Converts an object into a string suitable for use as a URL query string, using the given key as the param name.

Note: This method is defined as a default implementation for all Objects for Hash#to_query to work.



12
13
14
15
# File 'lib/req/query.rb', line 12

def to_query(key)
  require 'cgi' unless defined?(CGI) && defined?(CGI::escape)
  "#{CGI.escape(key.to_param)}=#{CGI.escape(to_param.to_s)}"
end